@@ -86,7 +86,7 @@ def create_video(scenario: Scenario,
 
     dpi = 150
     figsize = (5, 5)
-    rnd = MPRenderer(figsize=figsize)
+    rnd = MPRenderer(figsize=figsize, draw_params={"axis_visible": False})
     rnd.ax.axes.get_xaxis().set_visible(False)
     (ln,) = plt.plot([], [], animated=True)
 
@@ -96,7 +96,7 @@ def create_video(scenario: Scenario,
             planning_problem_set.draw(rnd)
 
         if dynamic_obstacles_ego is not None:
-            rnd.draw_list(dynamic_obstacles_ego, draw_params={'time_begin': 5, 'time_end': 5,
+            rnd.draw_list(dynamic_obstacles_ego, draw_params={'time_begin': 0, 'time_end': 0, "axis_visible": False,
                                           'dynamic_obstacle': {'vehicle_shape': {"occupancy": {"shape": {"rectangle": {
                                               "facecolor": "green"}}}}}})
         scenario.draw(renderer=rnd, draw_params={'time_begin': 0, 'time_end': 0})
